@@ -17,10 +17,11 @@ import (
 	"github.com/jwalton/gchalk"
 	"github.com/klauspost/compress/zstd"
 	"github.com/noborus/trdsql"
-	"github.com/pierrec/lz4"
+	"github.com/pierrec/lz4/v4"
 	"github.com/ulikunitz/xz"
 )
 
+// TableQuery is a query to use instead of TABLE.
 const TableQuery = "SELECT * FROM"
 
 // Cli wraps stdout and error output specification.
@@ -370,8 +371,8 @@ func Usage(flags *flag.FlagSet) {
 	}
 	fmt.Fprintf(flags.Output(), "\n%s\n", bold("Examples:"))
 	fmt.Fprintf(flags.Output(), "  $ trdsql \"SELECT c1,c2 FROM test.csv\"\n")
-	fmt.Fprintf(flags.Output(), "  $ trdsql -oltsv \"SELECT c1,c2 FROM test.json::items\"\n")
-	fmt.Fprintf(flags.Output(), "  $ cat test.csv | trdsql -i csv -oltsv \"SELECT c1,c2 FROM -\"\n")
+	fmt.Fprintf(flags.Output(), "  $ trdsql -oltsv \"SELECT c1,c2 FROM test.json::.items\"\n")
+	fmt.Fprintf(flags.Output(), "  $ cat test.csv | trdsql -icsv -oltsv \"SELECT c1,c2 FROM -\"\n")
 }
 
 func usageFlag(f *flag.Flag) string {
