@@ -28,7 +28,7 @@ func (w *JSONLWriter) PreWrite(columns []string, types []string) error {
 }
 
 // WriteRow is write one JSONL.
-func (w *JSONLWriter) WriteRow(values []interface{}, columns []string) error {
+func (w *JSONLWriter) WriteRow(values []any, columns []string) error {
 	m := orderedmap.New()
 	for i, col := range values {
 		m.Set(columns[i], compatibleJSON(col, w.needNULL, w.outNULL))
